/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.inlong.manager.pojo.node.es;

import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;

import java.util.Map;

@Data
@Builder
@NoArgsConstructor
@AllArgsConstructor
public class ElasticsearchRequest {

    /**
     * From index to start the search from. Defaults to 0.
     */
    private int from;

    /**
     * The number of search hits to return. Defaults to 10.
     */
    private int size;

    /**
     * Sets the search query for this request.
     */
    private ElasticsearchQueryInfo query;

    /**
     * Adds a sort against the given field name and the sort ordering.
     */
    private ElasticsearchQuerySortInfo sort;

    /**
     * Add an aggregation to perform as part of the search.
     */
    private Map<String, Map<String, ElasticsearchAggregationsTermsInfo>> aggregations;
}
