/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.inlong.sdk.sort.api;

import org.apache.inlong.sdk.sort.impl.SortClientImpl;
import org.apache.inlong.sdk.sort.impl.SortClientImplV2;

/**
 * Factory of {@link SortClient}
 */
public class SortClientFactory {

    /**
     * Create SortClient with default QueryConsumeConfig
     * @param config SortClientConfig
     * @return SortClient
     */
    public static SortClient createSortClient(SortClientConfig config) {
        return new SortClientImpl(config);
    }

    public static SortClient createSortClient(SortClientConfig config, QueryConsumeConfig queryConsumeConfig) {
        return new SortClientImpl(config, queryConsumeConfig);
    }

    public static SortClient createSortClientV2(SortClientConfig config) {
        return new SortClientImplV2(config);
    }

    public static SortClient createSortClientV2(SortClientConfig config, QueryConsumeConfig queryConsumeConfig) {
        return new SortClientImplV2(config, queryConsumeConfig);
    }
}
